@@ -355,7 +355,7 @@ draw_menu(int sel, int top, int edit_line)
   tabmsg_len = strlen(tabmsg);
 
   printf("\1#8\033[%d;%dH%s",
-	 TABMSG_ROW, 1+HSHIFT+((WIDTH-tabmsg_len)>>1), tabmsg);
+	 TABMSG_ROW, (79-tabmsg_len)>>1, tabmsg);
   printf("\1#0\033[%d;1H", END_ROW);
 }
 
@@ -424,10 +424,10 @@ static int show_fkey(int key)
     if (fkey == -1)
       return -2;
     
-    if( cm->fkeyhelp[fkey].textname && cm->fkeyhelp[fkey].background ) {
+    if( cm->fkeyhelp[fkey].textname ) {
 	 int slent = strlen(cm->fkeyhelp[fkey].textname);
          if (slent>4 &&
-	     !strcmp(cm->fkeyhelp[fkey].textname+slent-4,".c32")) {
+	     strcmp(cm->fkeyhelp[fkey].textname+slent-4,".txt")) {
 	     return fkey;
 	 }
     }
